@@ -46,7 +46,7 @@ void PgAuditLogToFile_csv_audit(StringInfo buf, const ErrorData *edata, int excl
 
   /* timestamp with milliseconds */
 
-  formatted_log_time = PgAuditLogToFile_format_now_timestamp();
+  formatted_log_time = PgAuditLogToFile_format_now_timestamp_millis();
   pgauditlogtofile_append_csv_value(buf, formatted_log_time);
   pfree(formatted_log_time);
   appendStringInfoCharMacro(buf, ',');
@@ -281,4 +281,4 @@ pgauditlogtofile_pgaudit_escape(StringInfo buf, char *line)
    * */
   if (line && *line != '\0')
     pgauditlogtofile_append_csv_value(buf, line + (*line == ',' ? 1 : 0));
-}
\ No newline at end of file
+}
